==> alicloud_impinteraction_sdk-1.8.6.tar.gz: android/src/main/java/com/aliyun/imp/flutter/sdk/alicloud_impinteraction_sdk/plugin/FPOfEvent.java <==
package com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.plugin;

import android.os.Handler;
import android.os.Looper;
import android.util.Pair;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.alibaba.fastjson.JSON;
import com.aliyun.roompaas.base.log.Logger;
import com.aliyun.roompaas.base.util.Utils;

import java.util.Map;

import io.flutter.plugin.common.EventChannel;

public class FPOfEvent extends FPOfBase {
    public static final String TAG = "FPOfEvent";

    private static final String EVENT_REQUEST_TOKEN = "onRequestToken";
    private static final String EVENT_KICK = "onKicked";

    private EventChannel eventChannel;

    @Nullable
    private static EventChannel.EventSink sEmitter;
    private static Handler sHandler;

    @Override
    protected String getMethodChannelName() {
        return "alicloud_impinteraction_sdk_event";
    }

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding binding) {
        super.onAttachedToEngine(binding);
        Logger.i("AAA Android", "onAttachedToEngine: ");

        // Prepare channel
        eventChannel = new EventChannel(binding.getBinaryMessenger(), getMethodChannelName());
        eventChannel.setStreamHandler(new EventChannel.StreamHandler() {
            @Override
            public void onListen(Object listener, EventChannel.EventSink eventSink) {
                Logger.i("AAA", "onListen: " + listener);
                sEmitter = eventSink;
            }

            @Override
            public void onCancel(Object listener) {
                Logger.i("AAA", "onCancel: " + listener);
            }
        });
    }

    public static void postEventViaEventChannel(String event, final Map<String, Object> params) {
        Logger.i("AAA Android", "sEmitter=" + sEmitter + "postEvent: " + event + ", params=" + params);
        if (sEmitter != null) {
            Logger.i("AAA Android", "postEventViaEventChannel: " + event);
            Map<String, Object> result = asM(new Pair<>("event", event), new Pair<>("params", params));
            String resultJonStr = result != null ? JSON.toJSONString(result) : "";
            ofHandler().post(() -> sEmitter.success(resultJonStr));
        }
    }

    private static Handler ofHandler() {
        if (sHandler == null) {
            sHandler = new Handler(Looper.getMainLooper());
        }

        return sHandler;
    }

    @Override
    public void destroy() {
        super.destroy();
        sEmitter = null;
        Utils.clear(sHandler);
    }
}

==> alicloud_impinteraction_sdk-1.8.15.tar.gz: android/src/main/java/com/aliyun/imp/flutter/sdk/alicloud_impinteraction_sdk/plugin/FPOfEvent.java <==
package com.aliyun.imp.flutter.sdk.alicloud_impinteraction_sdk.plugin;

import android.os.Handler;
import android.os.Looper;
import android.util.Pair;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.alibaba.fastjson.JSON;
import com.aliyun.roompaas.base.log.Logger;
import com.aliyun.roompaas.base.util.Utils;

import java.io.Serializable;
import java.util.Map;

import io.flutter.plugin.common.EventChannel;

public class FPOfEvent extends FPOfBase {
    public static final String TAG = "FPOfEvent";

    private static final String EVENT_REQUEST_TOKEN = "onRequestToken";
    private static final String EVENT_KICK = "onKicked";

    private EventChannel eventChannel;

    @Nullable
    private static EventChannel.EventSink sEmitter;
    private static Handler sHandler;

    @Override
    protected String getMethodChannelName() {
        return "alicloud_impinteraction_sdk_event";
    }

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding binding) {
        super.onAttachedToEngine(binding);
        Logger.i("AAA Android", "onAttachedToEngine: ");

        // Prepare channel
        eventChannel = new EventChannel(binding.getBinaryMessenger(), getMethodChannelName());
        eventChannel.setStreamHandler(new EventChannel.StreamHandler() {
            @Override
            public void onListen(Object listener, EventChannel.EventSink eventSink) {
                Logger.i("AAA", "onListen: " + listener);
                sEmitter = eventSink;
            }

            @Override
            public void onCancel(Object listener) {
                Logger.i("AAA", "onCancel: " + listener);
            }
        });
    }

    public static void postEventViaEventChannel(String event, Serializable serializable) {
        String paraJsonStr = serializable != null ? JSON.toJSONString(serializable) : "";
        Logger.i("AAA Android", "sEmitter=" + sEmitter + "postEvent: " + event + ", params=" + paraJsonStr);
        if (sEmitter != null) {
            Logger.i("AAA Android", "postEventViaEventChannel: " + event);
            Map<String, Object> result = asM(new Pair<>("event", event), new Pair<>("params", paraJsonStr));
            String resultJonStr = result != null ? JSON.toJSONString(result) : "";
            ofHandler().post(() -> sEmitter.success(resultJonStr));
        }
    }

    private static Handler ofHandler() {
        if (sHandler == null) {
            sHandler = new Handler(Looper.getMainLooper());
        }

        return sHandler;
    }

    @Override
    public void destroy() {
        super.destroy();
        sEmitter = null;
        Utils.clear(sHandler);
    }
}
